# Python Note

- A simple Python study and running online tool
- Just need your computer to run the python environment


use it, from pip：`pip install pythonnote`

then , only 2 line code , in any location:
```python
from pythonnote import run

run()
# or run(host="127.0.0.1", port=8080)
```

or use it, from source code : **clone source** then:
- 1.pip install these package >> `['uvicorn', 'fastapi', 'pydantic', 'aiofiles', 'jinja2']`
- 2.run python script : `pythonnote/web/main.py`



---


## index
![](https://img-blog.csdnimg.cn/20200620202301906.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)


## code list
all code list , you can add new code or 

edit code or note markdown 

or select contain keyword code use button 'Find'
![](imgs/code_view.png)

---

## select code
only see contain 'Sum' code
![](https://img-blog.csdnimg.cn/20200620202319563.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)


---

## code show
code detail view

you can run & debug & study & add code & note Markdown

you can edit you python code & run you code online !
![](https://img-blog.csdnimg.cn/20200620202344743.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)

---

## code markdown note
code's markdown note 

you can click Edit Button to Edit you note
![](https://img-blog.csdnimg.cn/20200620202407743.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)


---

## code markdown edit
code's markdown note can easy online edit, and 

you can click Save Button to Save you Edited note

left textarea to edit Markdown, right textarea show markdown's result view
![](https://img-blog.csdnimg.cn/20200618094528702.png?x-oss-process=image/watermark,type_ZmFuZ3poZW5naGVpdGk,shadow_10,text_aHR0cHM6Ly9ibG9nLmNzZG4ubmV0L2ppYW5nNDI1Nzc2MDI0,size_16,color_FFFFFF,t_70)